@@ -4,6 +4,7 @@
 #'
 #' @param \dots Arguments passed on to other methods
 #' @export
+#' @keywords internal
 #' @rdname bru_make_stack
 bru_make_stack <- function(...) {
   UseMethod("bru_make_stack")
@@ -14,9 +15,10 @@ bru_make_stack <- function(...) {
 #' * For `.bru_like`, a `bru_mapper_taylor` object
 #' * For `.bru_like_list`, a list of `bru_mapper_taylor` objects
 #' @param idx Output from `evaluate_index(...)`
+#' @param family_index integer specifying the family sequence index of the observation model
 #' @export
 #' @rdname bru_make_stack
-bru_make_stack.bru_like <- function(lhood, lin, idx, ...) {
+bru_make_stack.bru_like <- function(lhood, lin, idx, ..., family_index = 1L) {
   stopifnot(inherits(lin, "bru_mapper_taylor"))
   stopifnot(!is.null(lin[["offset"]]))
   stopifnot(is.null(lin[["jacobian"]]) || is.list(lin[["jacobian"]]))
@@ -28,20 +30,41 @@ bru_make_stack.bru_like <- function(lhood, lin, idx, ...) {
     BRU.response <- lhood$response_data[[lhood$response]]
   }
   nms <- names(lin$jacobian)
-  INLA::inla.stack(
-    list(
-      BRU.response = BRU.response,
-      BRU.E = lhood[["E"]],
-      BRU.Ntrials = lhood[["Ntrials"]],
-      BRU.weights = lhood[["weights"]],
-      BRU.offset = as.vector(lin$offset)
-    ),
-    A = lapply(nms, function(nm) {
-      lin$jacobian[[nm]][, idx[["inla_subset"]][[nm]], drop = FALSE]
-    }),
-    effects = idx[["idx_inla"]][nms],
-    remove.unused = FALSE
-  )
+  if (utils::packageVersion("INLA") <= "24.06.02") {
+    INLA::inla.stack(
+      list(
+        BRU.response = BRU.response,
+        BRU.E = lhood[["E"]],
+        BRU.Ntrials = lhood[["Ntrials"]],
+        BRU.weights = lhood[["weights"]],
+        BRU.scale = lhood[["scale"]],
+        BRU.offset = as.vector(lin$offset),
+        BRU.link = family_index
+      ),
+      A = lapply(nms, function(nm) {
+        lin$jacobian[[nm]][, idx[["inla_subset"]][[nm]], drop = FALSE]
+      }),
+      effects = idx[["idx_inla"]][nms],
+      remove.unused = FALSE
+    )
+  } else {
+    INLA::inla.stack(
+      list(
+        BRU.E = lhood[["E"]],
+        BRU.Ntrials = lhood[["Ntrials"]],
+        BRU.weights = lhood[["weights"]],
+        BRU.scale = lhood[["scale"]],
+        BRU.offset = as.vector(lin$offset),
+        BRU.link = family_index
+      ),
+      A = lapply(nms, function(nm) {
+        lin$jacobian[[nm]][, idx[["inla_subset"]][[nm]], drop = FALSE]
+      }),
+      effects = idx[["idx_inla"]][nms],
+      responses = list(BRU.response),
+      remove.unused = FALSE
+    )
+  }
 }
 
 #' @param lhoods A `bru_like_list` object
@@ -55,7 +78,8 @@ bru_make_stack.bru_like_list <- function(lhoods, lin, idx, ...) {
         bru_make_stack(
           lhood = lhoods[[lh_idx]],
           lin = lin[[lh_idx]],
-          idx = idx
+          idx = idx,
+          family_index = lh_idx
         )
       }
     )
@@ -67,7 +91,7 @@ bru_make_stack.bru_like_list <- function(lhoods, lin, idx, ...) {
   # above or in bru_make_stack.bru_like, and keep using remove.unused=FALSE here.
   stk <-
     do.call(
-      inlabru::inla.stack.mjoin,
+      bru_inla.stack.mjoin,
       c(stks, list(compress = TRUE, remove.unused = FALSE))
     )
 
