@@ -167,7 +167,7 @@ test_that("1D LGCP fitting, compressed format", {
   )
 
   data(Poisson2_1D, package = "inlabru", envir = environment())
-  x <- seq(0, 55, length = 50)
+  x <- seq(0, 55, length.out = 50)
   mesh1D <- fm_mesh_1d(x, boundary = "free")
   matern <- INLA::inla.spde2.pcmatern(
     mesh1D,
@@ -199,6 +199,28 @@ test_that("1D LGCP fitting, compressed format", {
     )
   )
 
+  # newdata <- data.frame(x = seq(0, 55, by = 1))
+  # pred0 <- data.frame(x = newdata$x, mean = lambda2_1D(newdata$x))
+  # pred1 <- predict(fit1, newdata, formula = ~ exp(spde1D + Intercept), n.samples = 1000)
+  # pred2 <- predict(fit2, newdata, formula = ~ exp(spde1D + Intercept), n.samples = 1000)
+  # library(ggplot2)
+  # ggplot() +
+  #   geom_line(aes(x = x, y = mean), color = "black", data = pred0) +
+  #   geom_line(aes(x = x, y = mean), color = "red", data = pred1) +
+  #   geom_ribbon(aes(x = x, ymin = q0.025, ymax = q0.975), fill = "red", alpha = 0.2, data = pred1) +
+  #   geom_line(aes(x = x, y = mean), color = "blue", data = pred2) +
+  #   geom_ribbon(aes(x = x, ymin = q0.025, ymax = q0.975), fill = "blue", alpha = 0.2, data = pred2)
+  #
+  # pred0 <- data.frame(x = newdata$x, mean = log(lambda2_1D(newdata$x)))
+  # pred1 <- predict(fit1, newdata, formula = ~ (spde1D + Intercept), n.samples = 1000)
+  # pred2 <- predict(fit2, newdata, formula = ~ (spde1D + Intercept), n.samples = 1000)
+  # ggplot() +
+  #   geom_line(aes(x = x, y = mean), color = "black", data = pred0) +
+  #   geom_line(aes(x = x, y = mean), color = "red", data = pred1) +
+  #   geom_ribbon(aes(x = x, ymin = q0.025, ymax = q0.975), fill = "red", alpha = 0.2, data = pred1) +
+  #   geom_line(aes(x = x, y = mean), color = "blue", data = pred2) +
+  #   geom_ribbon(aes(x = x, ymin = q0.025, ymax = q0.975), fill = "blue", alpha = 0.2, data = pred2)
+
   expect_equal(
     fit1$summary.hyperpar,
     fit2$summary.hyperpar,
